#
# spec file for package python-reportlab
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-reportlab
Version:        4.0.7
Release:        1.6
Summary:        The Reportlab Toolkit
License:        BSD-3-Clause
URL:            https://www.reportlab.com/
Source0:        https://files.pythonhosted.org/packages/source/r/reportlab/reportlab-%{version}.tar.gz
Source1:        encryption.gif
BuildRequires:  %{python_module Pillow >= 9.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  python-rpm-macros
Requires:       python-Pillow >= 9.0.0
Provides:       python-ReportLab = %{version}
Obsoletes:      python-ReportLab < %{version}
%ifpython2
Obsoletes:      %{oldpython}-ReportLab < %{version}
Provides:       %{oldpython}-ReportLab = %{version}
%endif
BuildArch:      noarch
%python_subpackages

%description
The ReportLab Toolkit. An Open Source Python library for generating PDFs and graphics.

%prep
%autosetup -p1 -n reportlab-%{version}
sed -i "1d" src/reportlab/lib/{formatters,fonts,corp,units,pagesizes,__init__,randomtext,logger,normalDate}.py
sed -i "1d" src/reportlab/graphics/{widgets/table,barcode/test,testdrawings,testshapes}.py # Fix non-executable bits

%build
export CFLAGS="%{optflags}"
%python_build --no-download-t1-files

mypython=%{expand:%%__%(pythons="%{pythons}"; echo ${pythons##python* })}
PYTHONPATH=$(readlink -f build/lib/) \
    $mypython docs/genAll.py

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export CFLAGS="%{optflags}"
export LANG=en_US.UTF-8
pushd tests
# make online tests offline
cp %{SOURCE1} .
sed -i 's@http://www.reportlab.com/rsrc/@@' test_*.py
###
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python runAll.py --verbosity=2
}

%files %{python_files}
%license LICENSE
%doc CHANGES.md README.txt docs/reportlab-userguide.pdf
%{python_sitelib}/reportlab/
%{python_sitelib}/reportlab-%{version}-py*.egg-info

%changelog
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.7:
  * allow testutils.makeSuiteForClasses to specify a prefix for
    test method names
  * SpiderChart can have direct draw flowable labels
  * fix and improve tests for python -mreportlab.lib.rl_accel
  * fix barchart 3D stacked case & fix barchart valueAxis
    reverseDirection behaviour.
  * fix importlib usage in reportlab init, reported by Frank
    Epperlein and others
  * add value axes extraMinMaxValues as aid to parallel axes
  * add styles str2alignment maps
    left/right/center/centre/justify etc
  * fix validators.isSubclassOf
  * test ddfStyle as instance first in textlabels.py
  * allow Pie Doughnut classes to control label class
- drop importlib.patch (upstream)
* Tue Oct  3 2023 Ondřej Súkup <mimi.vx@gmail.com>
- drop reportlab-missing-includes.patch
- add importlib.patch to fix support for python3.12
- update to 4.0.5:
  * add in test for alpha composite colour
  * Added an SvgPath class; as used in github.com/deeplook/svglib
  * Added a simple log axis ticklabeller class
  * Allow for strokeWidth in LineSwatch
  * update extension alias'
  * allow BalancedColumns to work in a container flowable (ie with no frame)
  * allow custom styles for inrowsplitStaart & inrowsplitend
  * setup.py test --failfast works
  * allow running all tests without renderPM support
  * AR made some changes to allow running without renderPM support
  * AR merged accessibility branch and released 4.0.0
  * initial support for rml ul ol dl tagging
  * added support for an ol/ul/dl caption paragraph
  * implement a safer toColor with rl_config.toColorCanUse option and rl_extended_literal_eval
  * added _ExpandedCellTupleEx for more tagging support
* Thu Sep 21 2023 Markéta Machová <mmachova@suse.com>
- Update to 3.6.13
  * fixes for python 3.12.0a1
  * tables.py error improvement
  * allow exclusions in tests in runAll.py and setup.py
  * implement a safer toColor with rl_config.toColorCanUse option
* Thu Jul 27 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Feb 16 2023 Dirk Müller <dmueller@suse.com>
- pick the primary interpreter for doc generation even if it is not "python3"
* Tue Jan 10 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 3.6.12:
  * fix dpi handling in renderPM.py; bug found by Terry Zhao Terry dot Zhao
    at fil dot com
  * attempt fix in rparsexml.py
  * add rl_settings.xmlParser with default 'lxml'
  * nano RHEL related fix to setup.py contributed by James Brown jbrown at
    easypost dot com
  * minor speedup in reportlab.graphics.transform functions
  * allow usage of freetype testpaths via rl_config/rl_settings textPaths
  * _renderPM.c remove parse_utf8, make pict_putrow same as for rlPyCairo
- CHANGES  3.6.11  24/06/2022
  * support HORIZONTAL2 & VERTICAL2 table cell backgrounds; as suggested by
    Sina Khelil < sina at khelil dot com >
  * support general LINEAR & RADIAL gradient table cell backgrounds
  * support ShowBoundaryValue in canv.drawImage
- CHANGES  3.6.10  31/05/2022
  * fix symlink looping in setup.py reported by Michał Górny &lt; mgorny at
    gentoo dot org &gt;
  * allow bearerBox attribute for some barcodes
  * require pillow>=9.0.0 patch contributed by Claude Paroz claude at
    2xlibre.net
  * Apply Claude Paroz  < claude at 2xlibre dot net > patch to assume hashlib
    md5 exists
  * ImageReader updated to allow deepcopy; similarly for
    doctemplate.onDrawStr
  * fix 3.11.0b2 regression in rl_safe_eval.
  * apply massive contribution for Table inRowSplit from Lennart Regebro <
    lregebro at shoobx dot com >
- CHANGES  3.6.9   22/03/2022
  * fix up _rl_accel.c 0.81 to allow better error messages and support python
    3.11.0a6
  * change the cibuildwheel setup to support macos M1 build
- CHANGES  3.6.8   28/02/2022
  * remove old Python2 constructs; patch from Claude Paroz < claude at
    2xlibre dot net >
* Sun Feb 20 2022 Dirk Müller <dmueller@suse.com>
- update to 3.6.7:
  * Remove use of cPickle
  * Remove unneccessary object inheritance
  * minor changes to python rendering in shapes.Drawing
  * remove jython (dead project no python3)
  * remove unicodeT/bytesT
  * import directly from string module
  * eliminate getBytesIO and getStringIO
  * remove unused and indirect imports
  * remove uniChr alias of chr
  * modify pdfdoc template to be eventually compatible with pikepdf
  * fix bug in table gradient bg
  * fix bug in validateSetattr (__dict__)
  * fix handling of ddfStyle in XLabel class
* Sun Jan  9 2022 Michael Ströder <michael@stroeder.com>
- Update to 3.6.5
  * only skip listwrap on for small height objects
  * changes to allow for deprecated stuff in Python-3.11
- Update to 3.6.4
  * try to improve multi-frag paragraph justification
  * fix justification condition
  * allow validator OneOf to take re.Pattern
- Update to 3.6.3
  * modernisation of para.py contribution from <Andrews Searle at BMC dot com>
  * many changes to .github workflows
  * changes to setup.py to support cibuildwheel
  * _FindSplitterMixin protect against deepcopy failure
  * allow textAnnotation to have QuadPoints keyword
* Tue Nov 16 2021 Matej Cepl <mcepl@suse.com>
- Increase verbosity of running the test suite.
* Tue Nov 16 2021 ecsos <ecsos@opensuse.org>
- Update to 3.6.2
  * add mock for urlopen calls so tests can run off line. Contribution by Antonio Trande sagitter at fedoraproject dot org
- Update to 3.6.1
  * create py-2-3 branch
  * Cease support for Python-2.7
- Update to 3.6.0
  * graphics improve some error messages for renderPM
  * changed lib.urilt.recursiveImport after errors in python3.10, reflect changes in readJPEGInfo
  * pdfutils readJPEGInfo extracts dpi if present defaults to (72, 72)
  * Image flowable allows a useDPI argument
  * paraparser annotate some errors
- Update to 3.5.68
  * Allow unicode PDFString to use encoding directly; fixes bug where colorspace indexes are broken
  * Ensure PIL images can be size checked
- Update to 3.5.67
  * fix obvious bug in renderPS.py cut'n'paste bah :(
  * fix bug saving to SpooledtemporaryFile's reported by Robert Schroll <rschroll at gmail.com>
  * fix bug in justified RTL paragraphs example & bugfix contributed by Moshe Uminer <mosheduminer at gmail.com>
  * fix regex deprecation reported by Jürgen Gmach <juergen.gmach at apis.de>
- Update to 3.5.66
  * add yieldNoneSplits utility function
  * fix BarChart so it lines can have markers and Nones in their data
- Update to 3.5.65
  * add ability to have lineplots in barcharts; no support yet for line markers
  * added checkAttr method to TypedPropertyCollection
- Update to 3.5.64
  * ensure setup.py works from sdist; bug reported by Antonio P. Sagitter (sagitter at fedoraproject.org)
  * restore broken MANIFEST.in somehow overwritten by Robin :(
- Update to 3.5.63
  * simplify annotateException and add better error messages for asUnicode/Bytes etc
  * improve embeddedHyphenation in paragraph.py
- Update to 3.5.62
  * add adjustableArrow widget
  * allow para tag borderPadding attribute
  * minor cosmetics in renderPM C extension and add fontSize setattr
  * allow a bounding box constraint in definePath
  * efficiency savings in text2Path
  * refactor transformation math and text2Path functionality
  * allow a renderPM plugin cairo backend package rlPyCairo
- Update to 3.5.61
  * Allow legend column control of vertical alignment
  * Allow renderTextMode attribute in reportlab.graphics.shapes.String
  * Allow renderTextMode drawString handling in renderPDF/PM/PS/SVG
  * Some fixes to fillMode handling
* Fri Feb 12 2021 Markéta Machová <mmachova@suse.com>
- Get rid of %%ifpython3, we could provide/obsolete more variants
* Mon Jan 11 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 3.5.59
  * Allow variant corners in Canvas.roundRect
  * Allow tables to have rounded corners
- Update to 3.5.58
  * added ddfStyle to Label
  * allowed for embedded(and ordinary)Hyphenation to pre-empt splitting when embeddedHyphenation>=2
  * fix extension escapePDF so it can handle unicode
  * fix poundsign in Ean5BarcodeWidget
  * Table can use __styledWrap__ for sizing
  * test fixes so 3.9 and 2.7 produce same pdf
- Update to 3.5.57
  * added .github action wheel.yml
  * micro change to userguide doc
* Wed Dec  9 2020 Markéta Machová <mmachova@suse.com>
- Update to 3.5.56
  * allow setting initial template cycle
  * fix for pillow 8.0.x
  * added trustedHosts & trustedSchemes settings
  * allow Drawing.outDir to be a callable
- Rebased reportlab-missing-includes.patch
* Thu Sep 24 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to 3.5.51
  * fix malloc(0) issue in \_rl_accel.c \_fp_str
    thanks to Hans-Peter Jansen <hpj@urpla.net> @ openSUSE
- remove fix-rl_accel-crash.patch
* Wed Sep 23 2020 Hans-Peter Jansen <hpj@urpla.net>
- add fix-rl_accel-crash.patch to fix a crash in rl_accel.
* Tue Sep 22 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to 3.5.50
  * Add BM ExtGState option (suggestion by tjj021 @ github
  * Fix memory leak in _renderPM.c
- Update to 3.5.49
  * ViewerPreferencesPDFDictionary add /Duplex as possibility
  * Doctemplate add support for all ViewerPreferencesPDFDictionary keys
  * fix bugs in USPS_4State; Barcode inherits from Flowable and object.
- Update to 3.5.48
  * bug fix for balanced column special case unsplittable half column
- Update to 3.5.47
  * try to limit table style cell ranges
* Wed Jul 22 2020 Michael Ströder <michael@stroeder.com>
- Update to 3.5.46
  * micro changes to normalDate
  * fix warnings about is not (detected in python 3.8b4)
  * implement PR #59 bug fix
  * add recursive ttf searching
  * sync with rlextra
  * fix Barchart axis crossing issue
* Wed Jul 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.5.44
  * Python 3.9 partial support
  * fix for improper <img> handling in paragraphs
  * ensure shapes save can do svg and regularize formats
  * allow TTF subfont selection with a PSName
  * experimental support for pie shading
* Sat Jan 18 2020 Matej Cepl <mcepl@suse.com>
- Update to 3.5.34:
  - change of the core repository (it is
    https://hg.reportlab.com/hg-public/reportlab, they stuck to
    Mercurial even when Bitbucket left it; issue reporting on the
    email list
    https://pairlist2.pair.net/mailman/listinfo/reportlab-users)
  - attempted restriction of the reportlab.lib.color.toColor
    function; fix of CVE-2019-17626 (bsc#1154370;
    bt#rptlab/reportlab#199)
  - fix bug in Pie3d reported by Eldon Ziegler <eldonz@atlanticdb.com>
  - fix bug in background splitting in repeatRows cases
  - small improvements to CandleSticks
  - created NotSet validator (use in  CandleStickProperties)
- add documentation
- remove python38_build.patch, because it has been included
  upstream
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- version update to 3.5.32
  * some chart efficiency changes
  * use clock in fontFinder contributed by Matěj Cepl @ bitbucket
  * improve recursive access and do some minor eval/exec fixes
  * improve use of eval/exec
- version update to 3.5.31
  * paraparser fix contributed by ravi prakash giri <raviprakashgiri@gmail.com>
- version update to 3.5.30
  * better support for candlestick charts using smartGetItem
- version update to 3.5.29
  * Support for candlestick charts and infilled pair plots
- version update to 3.5.28
  * improve support for AES encryption
- version update to 3.5.27
  * fix to justified para splits contributed by Niharika Singh <nsingh@shoobx.com>
  * fix BalanceColumn width calculation
  * preliminary support for AES encryption (contributed by https://github.com/talebi1)
- version update to 3.5.26
  * micro changes to normalDate
  * fix warnings about is not (detected in python 3.8b4)
  * implement PR #59 bug fix contributed by Vytis Banaitis
- version update to 3.5.25
  * add recursive ttf searching
  * sync with rlextra
  * fix Barchart axis crossing issue reported by Martin Jones (Zeidler)
- version update to 3.5.24
  * prepare for python3.8, drop support for python3.4
- rebase python38_build.patch
* Sat Oct 19 2019 Matej Cepl <mcepl@suse.com>
- Add python38_build.patch to work around depreceated (and now
  removed) function time.clock()
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- version update to 3.5.23
  * fix rendering to stdout doesn't work in python3
  * fix relative links within pdf broken
  * fix paragraph justification broken in the presence of no-break spaces
  * add wordSpace keyword to Canvas draw methods
  * fix an extra blank page shows up between two KeepTogether() groups
- version update to 3.5.22
  * Allow kewords in PDFResourceDictionary
  * fix DeprecationWarning: PY_SSIZE_T_CLEAN will be required for '#' formats
  * Allow AcroForm to have SigFlags
  * Bug Fixes and tests
* Tue May 21 2019 pgajdos@suse.com
- version update to 3.5.21
  * fix bug in legends
  * add extra table info in spanning error case
  * Preliminary MultiCol implementation
  * fix missing xrange import
  * allow rgb to have fractions of 1 in css colors
  * fix bug with a tag href not having a scheme
  * all0w LineChart/LinePlot area fills to differe from the stroke colour
  * add canvas setProducer method
  * more FrameBG changes vs BalancedColumns
  * fix bb issues #176/#177 reported by graingert & droidzone
  * more FrameBG fixes; added canvas cross method, frame static drawBoundary
  * fix stroking for frame background in container
  * add stroking for frame background
  * added axes tickStrokeWidth etc etc
  * added rl_setting.reserveTTFNotdef inspired by e3office at bitbucket (pr #50)
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to RELEASE 3.5.12
  * log axis handles rangeRound & avoidBoundspace
  * FrameBG can start with "frame" & frame-permanent" start options
- Update to RELEASE 3.5.11
  * Improve log axis ticks & grids
  * move some samples into tests
- Update to RELEASE 3.5.10
  * Bug fix for underline (contrib. Lennart Regebro @ bitbucket)
  * Paragraph indentation bug fix
  * Initial support for richtext graphics text labels
  * Initial support for log axes (ideas from hoel@germanlloyd.org)
- Update to RELEASE 3.5.9
  * add hyphenationMinWordLength to address PR #44 (contrib Michael V. Reztsov)
- Update to RELEASE 3.5.8
  * Allow structured barLabelFormat (suggestion from Ravinder Baid)
- Update to RELEASE 3.5.7
  * Fix tables.py splitting for line comands.
- Update to RELEASE 3.5.6
  * Restore DocTemplate seq attribute lost in rev c985bd7093ad (4405)
    version 3.4.41 bug report from Jim Parinisi jimandkimparinisi@yahoo.com
- Update to RELEASE 3.5.5
  * Bug fix underlined space in XPreformatted
- Update to RELEASE 3.5.4
  * Bug fix for Paragraph space bugs reported by Kayley Lane
  * Use local libart code by default (libart 2.3.21-3)
- Update to RELEASE 3.5.3
  * Bug fix release to make really simple paras work OK
    Reported by Kayley.Lane @ oracle.com
  * Use local libart by default
  * Use upgrade libart source to 2.3.21-3 https://salsa.debian.org/gnome-team/libart-lgpl@aa059539
- Update to RELEASE 3.5.2
  * Bug fix release to make th sdist work properly
- Update to RELEASE 3.5.1
  * Bug fix for infinite looping in Paragraph (likely caused by small available Widths).
    Reported by Kayley.Lane @ oracle.com
- Update to RELEASE 3.5
  * BalancedColumns flowable added
  * primitive hyphenation functionality (with Pyphen installed)
  * simple paragraphs now allow space shrinkage
  * mixed parallel / stacked barcharts mechanism
  * makeStream compression fix for python 3.x
  * reproducibility fixes
  * Bugfix for KeepWithNext and None
  * Fix pie chart issue
  * allow canvas filename to be a wrapped OS level file
  * added DocTemplate._makeCanvas
  * _text2Path fix
  * AcroForm improvements
  * added anchorAtXY parameter for images
  * fix PDF syntax error with no Outlines
  * fix bullet code
  * qrencoder fix
  * table minRowHeights support
  * stopped abusing builtins to aid compatibility
  * fix embedded font & fontfinder bugs
  * fix zero width paragraph layout error
  * doughnut charts support innerRadiusFraction
  * more controllable under and strike lines
- Remove upstream-included drop-requirements.patch
* Tue Jul 25 2017 jmatejek@suse.com
- drop-requirements.patch: do not list setuptools and pip in egg-info
  as requirements
  (fixes bsc#1049516, upstream issue https://bitbucket.org/rptlab/reportlab/issues/113 )
- set LANG variable correctly to help with test suite
  * note that test suite is broken, multiple tests fail and this does not stop build
  * causes of failure are spurious though
* Sat May  6 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Update to 3.4.0
  * We now support SVG as a format for embedded vector graphics.
  * The <barCodeFlowable> and <barCode> tags now support additional
    encodings.
  * We have considerably expanded our support for fillable forms
    within PDF files. The <textField> tag has many more attributes
    <checkboxField>, <radioField>, <choiceField> & <listboxField>
    which along with the new <textField> make possible PDF forms.
  * The <ul> & <ol> tags now support automatic style change for the
    start/type parameter, by using a space separated list fo start
    values
- Implement single-spec version
* Tue Mar 29 2016 dmueller@suse.com
- install LICENSE.txt
* Sat Nov  7 2015 freitag@opensuse.org
- Fixed source download link.
* Fri Jun  5 2015 kkaempf@suse.com
- Update to 3.2.0
  * Added proportional underlining specific to font sizes, set via
    the `underlineProportion` attribute of ParagraphStyles.
  * TrueType fonts: added support for cmaps 10 & 13
  * DocTemplate class now supports a boolean `displayDocTitle` argument.
  * TableofContents now supports a formatter argument to allow
    formatting of the displayed page numbers (eg for appendices etc).
  * Table `repeatRows` can now be a tuple of row numbers to allow
    incomplete ranges of rows to be repeated.
  * Tables now do pass instance.`spaceBefore` & `spaceAfter` to
    their split children when split
  * Several strangenesses were fixed in the pdfbase.pdfform module;
    Multiple usage is now allowed.
  * Error message fixes
  * Various environment fixes for Google Application Environment
  * Resource fixes
  * PDFDoc can now set the `Lang` attribute
  * canvas.drawString and similar now allow the character spacing
    to be set
  * Index of accented stuff has been improved
  * RTL code was improved
  * fix Propertyset.clone
  * `flowables.py`: fix ImageAndFlowables so it avoids testing
    negative availableWidth
* Fri Jun  5 2015 kkaempf@suse.com
- Update to 3.1
  * support for emoji
  * improved pip-based installers
* Fri Jun  5 2015 kkaempf@suse.com
- Update to 3.0
  * ReportLab 3.0 now supports Python 2.7, 3.3 and higher.
  * There has been a substantial internal rewrite to ensure
    consistent use of unicode strings for natural-language text,
    and of bytes for all file format internals.
  * Python 3.x compatibility
  * New features
  - Add ability to output greyscale and 1-bit PIL images without
    conversion to RGB. (contributed by Matthew Duggan)
  - highlight annotation (contributed by Ben Echols)
  * Other
  - numerous very minor fixes, visible through BitBucket.
* Sun Nov 24 2013 kkaempf@suse.com
- Update to version 2.7
  * Charts / graphics enhancements
  - Added SimpleTimeSeriesPlot
  - added _computeMaxSpace
  - added in lineStyle (for bars)
  - improved SVG rendering
  - Pie Chart now has an `innerRadiusFraction` to allow doughnut-like
    appearance for 2d charts
  * Charts/graphics bug fixes
  - piecharts.py: fix Pie3d __init__ to call its superclass
  - linecharts.py: fix swatch creation
  - fixed `y` axis in the simple time series plot
  * PDF
  - Fixes to testshapes & pdfform resetting
  - colors.py
  - various minor fixes
  * Platypus
  - Defined a small bullet rather than a big circle as the default for unordered lists
  - fixed attribute spelling bug
  - fixed CJK + endDots
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 2.7
  + No relative ChangeLog entry
* Thu Jan 24 2013 p.drouand@gmail.com
- Update to version 2.6:
  * General changes
  - Manuals have been reformatted with more pleasing code snippets and tables of
    contents, and reviewed and expanded
  * Flowing documents (Platypus):
  - Added support for HTML-style list objects
  - Added flexible mechanism for drawing bullets
  - Allowed XPreformatted objects to use Asian line wrapping
  - Added an 'autoNextPageTemplate' attribute to PageTemplates.  For example you
    can now set up a 'chapter first page template' which will always be followed
    by a 'continuation template' on the next page break, saving the programmer from
    having to issue control flow commands in the story.
  - added a TopPadder flowable, which will 'wrap' another Flowable and move it
    to the bottom of the current page.
  - More helpful error messages when large tables cannot be rendered
  - Documentation for images within text (test_032_images)
  - Trailing dots for use on contents pages
  * Charts and graphics:
  - Support for UPCA bar codes
  - We now have a semi-intelligent system for labelling pie charts with
    callout lines.  Thanks to James Martin-Collar, a maths student at Warwick
    University, who did this as his summer internship.
  - Axes - added startOffset and endOffset properties; allowed for axis
    background annotations.
  - Bar charts - allow more control of z Index (i.e. drawing order of axes and
    lines)
  - Pie charts - fixed bugs in 3d appearance
  - SVG output back end has seen some bugs fixed and now outputs resizeable SVG
* Fri May 25 2012 toddrme2178@gmail.com
- Clean up spec file
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Sep 20 2011 saschpe@suse.de
- Fix non-executable bit rpmlint warning
* Mon May 30 2011 alexandre@exatati.com.br
- Add Provides and Obsoletes to python-ReportLab in spec file to
  better behaviour in 11.1.
* Tue Apr 12 2011 alexandre@exatati.com.br
- Update to 2.5:
  - Please readme CHANGES.txt.
- Regenerate spec file with py2pack;
- Add CHANGES.txt and README.txt files as documentation;
- Bzip2 source code.
* Thu Jan 21 2010 alexandre@exatati.com.br
- Update to 2.4.
* Mon Dec 28 2009 alexandre@exatati.com.br
- New ReportLab package (2.3) for openSUSE, now in d:l:py.
